<?php

namespace Drupal\lb_block_decorator\EventSubscriber;

use Drupal\Core\Url;
use Drupal\lb_plus\Event\BlockToolIndicatorEvent;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Block Decorator tool indicator.
 */
class BlockToolIndicators implements EventSubscriberInterface {

  use StringTranslationTrait;

  public function __construct(
    protected ModuleHandlerInterface $moduleHandler,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {}

  public function onToolIndicator(BlockToolIndicatorEvent $event) {
    $build = $event->getBuild();

    // Decorate block.
    $build['#attached']['drupalSettings']['navigationPlus']['toolIndicators']['links']['block_indicator'][$event->getUuid()] = Url::fromRoute('lb_block_decorator.decorate', [
      'section_storage_type' => $event->getStorageType(),
      'section_storage' => $event->getStorageId(),
      'delta' => $event->getSectionDelta(),
      'uuid' => $event->getUuid(),
    ])->toString();

    $event->setBuild($build);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      BlockToolIndicatorEvent::class => ['onToolIndicator'],
    ];
  }

}
