<?php

namespace Drupal\lb_block_decorator\EventSubscriber;

use Drupal\lb_block_decorator\BlockDecoratorPluginManager;
use Drupal\layout_builder\Event\SectionComponentBuildRenderArrayEvent;
use Drupal\layout_builder\LayoutBuilderEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Layout Builder Block Decorator event subscriber.
 *
 * @package Drupal\lb_block_decorator\EventSubscriber
 */
class SectionComponentDecorator implements EventSubscriberInterface {

  /**
   * The BlockDecorator Plugin Manager.
   *
   * @var \Drupal\lb_block_decorator\BlockDecoratorPluginManager
   */
  protected $blockDecoratorManager;

  /**
   * Constructs a new FormAjaxSubscriber.
   *
   * @param \Drupal\lb_block_decorator\BlockDecoratorPluginManager $block_decorator_manager
   *   The block decorator plugin manager.
   */
  public function __construct(BlockDecoratorPluginManager $block_decorator_manager) {
    $this->blockDecoratorManager = $block_decorator_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[LayoutBuilderEvents::SECTION_COMPONENT_BUILD_RENDER_ARRAY] = [
      'onPostRender',
    ];
    return $events;
  }

  /**
   * Wrap the output with the stored wrapper data.
   *
   * @param \Drupal\layout_builder\Event\SectionComponentBuildRenderArrayEvent $event
   *   The section component build render array event.
   */
  public function onPostRender(SectionComponentBuildRenderArrayEvent $event) {
    $component = $event->getComponent();
    $decorator_id = $component->get('decorator_id') ?? [];
    if (!$decorator_id) {
      return;
    }

    /** @var \Drupal\lb_block_decorator\BlockDecoratorPluginBase $decorator_plugin */
    $decorator_plugin = $this->blockDecoratorManager->createInstance($decorator_id);
    $decorator_plugin->setConfiguration($component->get('decorator_configuration') ?? []);
    $build = $event->getBuild() ?? [];
    $decorator_plugin->onBuildRenderArray($build);
    $event->setBuild($build);
  }

}
