<?php

namespace Drupal\lb_block_decorator\Plugin\BlockDecorator;

use Drupal\Component\Utility\Html;
use Drupal\Core\Form\FormStateInterface;
use Drupal\lb_block_decorator\BlockDecoratorPluginBase;

/**
 * Plugin implementation for decorating blocks with html classes.
 *
 * @BlockDecorator(
 *   id = "html_class",
 *   label = @Translation("HTML Class"),
 *   description = @Translation("Allows adding one or more classes to a block.")
 * )
 */
class HtmlClass extends BlockDecoratorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['classes' => []];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();
    $form['classes'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Classes'),
      '#required' => TRUE,
      '#default_value' => implode(' ', $config['classes'] ?? []),
      '#description' => $this->t('Enter a comma or space delimited list of html class you want to add to the block.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $escaped = Html::escape($form_state->getValue('classes'));
    $classes = explode(' ', $escaped);
    if (count($classes) === 1 && mb_strpos(',', $classes[0]) !== FALSE) {
      $classes = explode(',', $classes[0]);
    }
    $component = $form_state->get('section_component');
    $component->set('decorator_id', $this->getPluginId());
    $component->set('decorator_configuration', ['classes' => $classes]);
  }

  /**
   * {@inheritdoc}
   */
  public function onBuildRenderArray(array &$build): void {
    $data = $this->getConfiguration();
    $classes = $data['classes'] ?? [];
    if ($classes) {
      $build['#attributes']['class'] = array_merge(
        !empty($build['#attributes']['class']) ? $build['#attributes']['class'] : [],
        $classes
      );
    }
  }

}
