<?php

namespace Drupal\lb_block_decorator\Plugin\BlockDecorator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\lb_block_decorator\BlockDecoratorPluginBase;

/**
 * Plugin implementation for decorating blocks with a wrapper.
 *
 * @BlockDecorator(
 *   id = "wrapper",
 *   label = @Translation("Wrapper"),
 *   description = @Translation("Allows wrapping a block using custom markup.")
 * )
 */
class Wrapper extends BlockDecoratorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['prefix' => '', 'suffix' => ''];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();
    $form['prefix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Prefix'),
      '#default_value' => $config['prefix'] ?? '',
    ];
    $form['suffix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Suffix'),
      '#default_value' => $config['suffix'] ?? '',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $component = $form_state->get('section_component');
    $component->set('decorator_id', $this->getPluginId());
    $component->set('decorator_configuration', [
      'prefix' => $form_state->getValue('prefix'),
      'suffix' => $form_state->getValue('suffix'),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function onBuildRenderArray(array &$build): void {
    $data = $this->getConfiguration();
    $prefix = $data['prefix'] ?? '';
    if ($prefix) {
      $build['#prefix'] = $prefix;
    }
    $suffix = $data['suffix'] ?? '';
    if ($suffix) {
      $build['#suffix'] = $suffix;
    }
  }

}
