<?php

declare(strict_types=1);

namespace Drupal\lb_block_decorator\Plugin\Tool;

use Drupal\Core\Entity\EntityInterface;
use Drupal\navigation_plus\Attribute\Tool;
use Drupal\navigation_plus\ToolPluginBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;

/**
 * Plugin implementation of the tool.
 */
#[Tool(
  id: 'block_decorator',
  label: new TranslatableMarkup('Block decorator'),
  hot_key: 'w',
  weight: 300,
)]
final class BlockDecorator extends ToolPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getIconsPath(): array {
    $path = $this->extensionList->getPath('lb_block_decorator');
    return [
      'mouse_icon' => "url('/$path/assets/palette-bold.svg') 4 9",
      'toolbar_button_icons' => [
        'block_decorator' => "/$path/assets/palette.svg",
      ],
      'tool_indicator_icons' => [
        'block' => "/$path/assets/palette-bold.svg",
      ],
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function addAttachments(array &$attachments): void {
    $attachments['library'][] = 'lb_block_decorator/tool';
  }


  /**
   * {@inheritdoc}
   */
  public function applies(EntityInterface $entity): bool {
    $entity_type_id = $entity->getEntityTypeId();
    $bundle = $entity->bundle();

    // @todo We are getting the entity from NavigationPlusUi->deriveEntityFromRoute.
    // @todo We need to figure out a way to get the actual view mode here and
    // @todo not hard code 'default'.
    $view_display = $this->entityDisplayRepository()->getViewDisplay($entity_type_id, $bundle, 'default');

    if ($view_display) {
      // Check if Layout Builder is enabled for this view display.
      return !empty($view_display->getThirdPartySetting('layout_builder', 'enabled', FALSE));
    }
    return FALSE;
  }

  protected function entityDisplayRepository(): EntityDisplayRepositoryInterface {
    return \Drupal::service('entity_display.repository');
  }

}
